==> openshift-model-monitoring-5.9.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/StorageSpecBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StorageSpecBuilder extends io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.StorageSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.StorageSpec,io.fabric8.openshift.api.model.monitoring.v1.StorageSpecBuilder>{
  public StorageSpecBuilder() {
    this(false);
  }
  public StorageSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new StorageSpec(), validationEnabled);
  }
  public StorageSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StorageSpec(), validationEnabled);
  }
  public StorageSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.StorageSpec instance) {
    this(fluent, instance, false);
  }
  public StorageSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.StorageSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDisableMountSubPath(instance.getDisableMountSubPath()); 
    fluent.withEmptyDir(instance.getEmptyDir()); 
    fluent.withVolumeClaimTemplate(instance.getVolumeClaimTemplate()); 
    this.validationEnabled = validationEnabled; 
  }
  public StorageSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.StorageSpec instance) {
    this(instance,false);
  }
  public StorageSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.StorageSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDisableMountSubPath(instance.getDisableMountSubPath()); 
    this.withEmptyDir(instance.getEmptyDir()); 
    this.withVolumeClaimTemplate(instance.getVolumeClaimTemplate()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.StorageSpec build() {
    StorageSpec buildable = new StorageSpec(fluent.getDisableMountSubPath(),fluent.getEmptyDir(),fluent.getVolumeClaimTemplate());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StorageSpecBuilder that = (StorageSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.10.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/StorageSpecBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StorageSpecBuilder extends io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.StorageSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.StorageSpec,io.fabric8.openshift.api.model.monitoring.v1.StorageSpecBuilder>{
  public StorageSpecBuilder() {
    this(false);
  }
  public StorageSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new StorageSpec(), validationEnabled);
  }
  public StorageSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StorageSpec(), validationEnabled);
  }
  public StorageSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.StorageSpec instance) {
    this(fluent, instance, false);
  }
  public StorageSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.StorageSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDisableMountSubPath(instance.getDisableMountSubPath()); 
    fluent.withEmptyDir(instance.getEmptyDir()); 
    fluent.withVolumeClaimTemplate(instance.getVolumeClaimTemplate()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StorageSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.StorageSpec instance) {
    this(instance,false);
  }
  public StorageSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.StorageSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDisableMountSubPath(instance.getDisableMountSubPath()); 
    this.withEmptyDir(instance.getEmptyDir()); 
    this.withVolumeClaimTemplate(instance.getVolumeClaimTemplate()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.StorageSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.StorageSpec build() {
    StorageSpec buildable = new StorageSpec(fluent.getDisableMountSubPath(),fluent.getEmptyDir(),fluent.getVolumeClaimTemplate());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StorageSpecBuilder that = (StorageSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
